<?php
namespace CreativeButtons;

define( "CBTNS_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "CBTNS_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );
class ClassCreativeButtons {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function cbtns_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'cbtns_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function cbtns_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'cbtns_the_buttons_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/cbtns-creative-buttons.php' );
	}

	public function cbtns_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\CBTNSCreativeButtons() );
	}

	// Register Category
	function cbtns_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwd-creative-buttons-category',
			[
				'title' => esc_html__( 'BWD Creative Buttons', 'bwd-creative-buttons' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function cbtns_all_assets_for_the_public(){
		$all_css_js_file = array(
            'cbtns_buttons_creative-buttons_css' => array('cbtns_path_define'=>'https://bwd-elementor-addons-pro.netlify.app/creative-buttons/creative-buttons.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['cbtns_path_define'], null, '2.1', 'all');
        }
	}
	public function cbtns_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'cbtns_buttons_admin_main_css' => array('cbtns_path_admin_define'=>CBTNS_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['cbtns_path_admin_define'], null, '2.1', 'all');
        }
	}
	
	public function __construct() {

		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'cbtns_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'cbtns_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'cbtns_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'cbtns_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'cbtns_admin_editor_scripts' ] );
	}
}

// Instantiate Plugin Class
ClassCreativeButtons::instance();